<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Concerns\HasTimestamps;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

/**
 * @property int       $id
 * @property string    $name
 * @property string    $short_name
 * @property string    $level1_actual_label
 * @property string    $level1_preconized_label
 * @property string    $level1_file
 * @property string    $level1_description
 * @property int       $level1_difficulty
 * @property int       $level1_cost
 * @property int       $level1_duration
 * @property int       $level1_assistance
 * @property string    $level1_info
 * @property string    $level2_actual_label
 * @property string    $level2_preconized_label
 * @property string    $level2_file
 * @property string    $level2_description
 * @property int       $level2_difficulty
 * @property int       $level2_cost
 * @property int       $level2_duration
 * @property int       $level2_assistance
 * @property string    $level2_info
 * @property string    $level3_actual_label
 * @property string    $level3_preconized_label
 * @property string    $level3_description
 * @property string    $level3_info
 * @property int       $level3_difficulty
 * @property int       $level3_cost
 * @property int       $level3_duration
 * @property int       $level3_assistance
 * @property string    $level3_file
 * @property \DateTime $created_at
 * @property \DateTime $updated_at
 */
class Measure extends Model
{
    use HasFactory;
    use HasTimestamps;

    protected $casts = [
        'level1_difficulty' => 'int',
        'level1_cost' => 'int',
        'level1_duration' => 'int',
        'level1_assistance' => 'int',
        'level2_difficulty' => 'int',
        'level2_cost' => 'int',
        'level2_duration' => 'int',
        'level2_assistance' => 'int',
        'level3_difficulty' => 'int',
        'level3_cost' => 'int',
        'level3_duration' => 'int',
        'level3_assistance' => 'int',
    ];

    public function withConvertedLevels(): array
    {
        $m = $this->toArray();

        $m['levels'] = [];

        for ($i = 0; $i < 3; ++$i) {
            $niveau = $i + 1;
            $m['levels'][$i] = [
                'actual_label' => $this->{'level' . $niveau . '_actual_label'},
                'preconized_label' => $this->{'level' . $niveau . '_preconized_label'},
                'description' => $this->{'level' . $niveau . '_description'},
                'difficulty' => $this->{'level' . $niveau . '_difficulty'},
                'cost' => $this->{'level' . $niveau . '_cost'},
                'duration' => $this->{'level' . $niveau . '_duration'},
                'assistance' => $this->{'level' . $niveau . '_assistance'},
                'info' => $this->{'level' . $niveau . '_info'},
                'file' => $this->{'level' . $niveau . '_file'},
            ];
        }

        return $m;
    }
}
