<?php

namespace Database\Seeders;

use App\Models\Danger;
use App\Models\Evaluation;
use App\Models\EvaluationMeasure;
use App\Models\Measure;
use App\Models\Organization;
use App\Models\User;
use Illuminate\Database\Seeder;

class OrganizationSeeder extends Seeder
{
    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {
        Organization::factory(5)->create()->each(function (Organization $org) {
            $org->users()->saveMany(User::factory(5)->make());
            $org->evaluations()->saveMany(Evaluation::factory(5)->make());

            foreach ($org->evaluations as $eval) {
                if ($eval->current_step > 1) {
                    $dangers = Danger::all();

                    $dangerLevels = $dangers->map(function (Danger $danger) {
                        return $danger->levels()->inRandomOrder()->first();
                    });

                    $eval->dangerLevels()->saveMany($dangerLevels);
                }

                if ($eval->current_step > 2) {
                    $measures = Measure::all();
                    $evalMeasures = $measures->map(function (Measure $m) {
                        return EvaluationMeasure::factory()->make(['measure_id' => $m->id]);
                    });
                    $eval->evaluationMeasures()->saveMany($evalMeasures);
                }
            }
        });
    }
}
