import axios from 'axios';
import toaster from '../utils/toaster.js';

export default {
    state: { all: [], errors: null},
    mutations: {
        setEvaluations (state, items) {
            state.all = items;
        },
        updateEvaluation (state, item) {
            let index = state.all.findIndex(s => s.id == item.id)
            state.all = state.all.filter(s => s.id != item.id)
            state.all.splice(index, 0, item)
        },
        deleteEvaluation (state, item) {
            state.all = state.all.filter(u => u.id != item.id)
        },
        setErrors(state, errors) {
            state.errors = errors
        }
    },
    actions: {
        getEvaluations( {commit} ) {
            const req = axios.get(`/api/evaluations`);
            req.then(res => {
                commit('setEvaluations', res.data);
            }).catch(err => {
                console.log('could not get evaluations', err)
            })
            return req;
        },
        updateEvaluation( {commit}, item ) {
            const req = item.id ? axios.put(`/api/evaluations/${item.id}`, item) : axios.post(`/api/evaluations`, item);
            req.then(res => {
                commit('updateEvaluation', res.data);
                toaster(this._vm, 'Mise à jour effectuée', 'bg-success', 'check' )
            }).catch(err => {
                console.log('could not update evaluation', err)
                commit('setErrors', {errors: err.response.data, status: err.response.status})
            })
            return req;
        },
        saveEvaluation( {commit, dispatch}, item ) {
            return dispatch('updateEvaluation', {...item, draft: 0})
        },
        saveDraftEvaluation( {commit, dispatch}, item ) {
            return dispatch('updateEvaluation', {...item, draft: 1})
        },
        deleteEvaluation( {commit}, org ) {
            console.log('deleteEvaluation', org)
            const req = axios.delete(`/api/evaluations/${org.id}`, org);
            req.then(res => {
                commit('deleteEvaluation', org);
                toaster(this._vm, 'Suppression effectuée', 'bg-success', 'check' )
            }).catch(err => {
                console.log('could not delete evaluation', err)
            })
            return req;
        }
    }

};
